@@ -24,36 +24,14 @@
 #' test  <- rasterSource(x, grid)
 #' image(test, axe = FALSE, main = "Spatial distribution by Persistent Nocturnal Lights from DMSP")
 #'
-#'@source Data avaliable \url{https://www.ospo.noaa.gov/Operations/DMSP/index.html}
+#'@source Data avaliable \url{https://www.nesdis.noaa.gov/current-satellite-missions/currently-flying/defense-meteorological-satellite-program}
 #'@details About the DMSP and example data \url{https://en.wikipedia.org/wiki/Defense_Meteorological_Satellite_Program}
 
 
 rasterSource <- function(r,grid,nlevels="all",conservative = TRUE,verbose = TRUE){
 
-  if(grid$map_proj == 1){
-    dx    <- grid$DX*1000            # nocov start
-    dy    <- grid$DX*1000            # using meters
-    ncols <- grid$Horizontal[1]
-    nrows <- grid$Horizontal[2]
-
-    # projcoords <- rgdal::project(grid$coords,grid$geogrd.proj)
-    pontos     <- sf::st_multipoint(x = grid$coords, dim = "XY")
-    coords     <- sf::st_sfc(x = pontos, crs = "+proj=longlat")
-    transform  <- sf::st_transform(x = coords, crs = grid$geogrd.proj)
-    projcoords <- sf::st_coordinates(transform)[,1:2]
-
-    xmn <- projcoords[1,1] - dx/2.0  # Left border
-    ymx <- projcoords[1,2] + dy/2.0  # upper border
-    xmx <- xmn + ncols*dx            # Right border
-    ymn <- ymx - nrows*dy            # Bottom border
-    # Create a raster
-    box <- suppressWarnings(
-      raster::raster(resolution = dx,
-                     xmn = xmn,
-                     xmx = xmx,
-                     ymn = ymn,
-                     ymx = ymx,
-                     crs = grid$geogrd.proj))  # nocov end
+  if(grid$map_proj %in% c(1,2,3,6)){
+    box   <- grid$r
   }else{
     col   <- grid$Horizontal[1]
     rol   <- grid$Horizontal[2]
@@ -65,9 +43,6 @@ rasterSource <- function(r,grid,nlevels="all",conservative = TRUE,verbose = TRUE
   }
 
   if(is.na(grid$z[1])){
-    # if(conservative)
-    #   total_box <- cellStats(raster::crop(r,box),"sum",na.rm=TRUE)
-
     # to reduce the memory
     box_ll <- suppressWarnings( projectRaster(box, crs='+proj=longlat') )
     r      <- raster::crop(r,raster::extent(box_ll))
@@ -94,7 +69,6 @@ rasterSource <- function(r,grid,nlevels="all",conservative = TRUE,verbose = TRUE
     }else{
       nlevels <- nlevels
     }
-    # total_box <- cellStats(raster::crop(r,box),"sum",na.rm=TRUE)
 
     r    <- suppressWarnings(raster::projectRaster(r,crs = raster::crs(box))) # to the new projection
     r    <- raster::crop(r,box)
@@ -106,10 +80,12 @@ rasterSource <- function(r,grid,nlevels="all",conservative = TRUE,verbose = TRUE
     for(i in 1:nlevels){
       X[,,i] = Y
     }
-    # X    <- X * total_box[1:nlevels]/sum(X) # to conserve mass
 
-    if(verbose)
+    if(verbose){
+      col   <- grid$Horizontal[1]
+      rol   <- grid$Horizontal[2]
       cat(paste("Grid output:",col,"columns",rol,"rows",nlevels,"levels\n"))
+    }
   }
 
   return(X)
